@@ -218,6 +218,7 @@ Class Reference
 import os
 from contextlib import contextmanager
 from typing import Iterable, Iterator, Optional, Tuple, Dict, Any, Set, TYPE_CHECKING, Union
+from dataclasses import dataclass
 
 from . import _yaml, utils
 from .node import MappingNode
@@ -259,6 +260,12 @@ class SourceError(BstError):
         super().__init__(message, detail=detail, domain=ErrorDomain.SOURCE, reason=reason, temporary=temporary)
 
 
+@dataclass
+class AliasSubstitution:
+    _effective_alias: str
+    _mirror: Union[SourceMirror, str]
+
+
 class SourceFetcher:
     """SourceFetcher()
 
@@ -280,7 +287,7 @@ class SourceFetcher:
     #############################################################
     #                      Abstract Methods                     #
     #############################################################
-    def fetch(self, alias_override: Optional[Union[str, SourceMirror]] = None, **kwargs) -> None:
+    def fetch(self, alias_override: Optional[AliasSubstitution] = None, **kwargs) -> None:
         """Fetch remote sources and mirror them locally, ensuring at least
         that the specific reference is cached locally.
 
@@ -387,7 +394,7 @@ class Source(Plugin):
         meta: MetaSource,
         variables: Variables,
         *,
-        alias_override: Optional[Tuple[str, Union[str, SourceMirror]]] = None,
+        alias_override: Optional[Tuple[str, AliasSubstitution]] = None,
         unique_id: Optional[int] = None,
     ):
         # Set element_name member before parent init, as needed for debug messaging
@@ -699,7 +706,7 @@ class Source(Plugin):
         self,
         url: str,
         *,
-        alias_override: Optional[Union[str, SourceMirror]] = None,
+        alias_override: Optional[AliasSubstitution] = None,
         primary: bool = True,
         suffix: Optional[str] = None,
         extra_data: Optional[Dict[str, Any]] = None,
@@ -745,7 +752,7 @@ class Source(Plugin):
 
             if self.__alias_override is not None:
                 override_alias = self.__alias_override[0]
-                override_mirror = self.__alias_override[1]
+                override_subst = self.__alias_override[1]
 
                 # Implicit alias overrides may only be done for one
                 # specific alias, so that sources that fetch from multiple
@@ -756,16 +763,19 @@ class Source(Plugin):
                     return url
 
             elif alias_override is not None:
-                override_mirror = alias_override
+                override_subst = alias_override
 
             # The default source mirror will give prefix URLs
-            if isinstance(override_mirror, str):
-                return override_mirror + url_body
+            if isinstance(override_subst._mirror, str):
+                return override_subst._mirror + url_body
             #
             # Delegate the URL translation to the SourceMirror plugin
             #
-            return override_mirror.translate_url(
-                alias=url_alias, alias_url=project_alias_url, source_url=url_body, extra_data=extra_data
+            return override_subst._mirror.translate_url(
+                alias=override_subst._effective_alias,
+                alias_url=project_alias_url,
+                source_url=url_body,
+                extra_data=extra_data,
             )
         else:
             return project.translate_url(url, source=self, first_pass=self.__first_pass)
